import { spread, insert, createComponent, effect, template, setAttribute, style } from 'solid-js/web';
import { onMount, onCleanup, mergeProps, getOwner, createSignal, runWithOwner, Show, createEffect, on, createResource, ErrorBoundary, Suspense } from 'solid-js';
import { createStore } from 'solid-js/store';

var access = (v) => typeof v === "function" && !v.length ? v() : v;

// src/index.ts
var createIntersectionObserver = (elements, onChange, options) => {
  const instance = new IntersectionObserver(onChange, options);
  const add = (el) => instance.observe(access(el));
  const remove = (el) => instance.unobserve(access(el));
  const start = () => access(elements).forEach((el) => add(el));
  const stop = () => instance.disconnect();
  onMount(start);
  onCleanup(stop);
  return [add, { remove, start, stop, instance }];
};

const getPadding$1 = (aspectRatio) => {
    const config = {
        "1:1": {
            "padding-top": "100%"
        },
        "16:9": {
            "padding-top": "56.25%"
        },
        "4:3": {
            "padding-top": "75%"
        },
        "3:2": {
            "padding-top": "66.66%"
        },
        "8.5": {
            "padding-top": "62.5%"
        }
    };
    return config[aspectRatio];
};
const createStyleSheet = (href) => {
    const link = document.createElement(`link`);
    link.type = `text/css`;
    link.rel = `stylesheet`;
    link.href = href;
    document.querySelectorAll(`head`)[0].append(link);
};
const createTestId = (id) => ({
    ...{"BASE_URL":"/","MODE":"production","DEV":false,"PROD":true}?.NODE_ENV === "test" && { "data-testid": id }
});

const _tmpl$$z = /*#__PURE__*/ template(`<div class="observer-solid-social"></div>`, 2), _tmpl$2$1 = /*#__PURE__*/ template(`<div class="placeholder-solid-social"></div>`, 2);
const GeneralObserver = properties => {
    const properties_ = mergeProps({
        height: 0
    }, properties);
    const owner = getOwner();
    let observerReference;
    const [isVisible, setVisible] = createSignal(false);
    createIntersectionObserver(() => [observerReference], ([entry]) => entry.intersectionRatio > 0 && setVisible(true) && owner && runWithOwner(owner, () => properties_.onEnter?.()), {
        root: undefined,
        rootMargin: '400px',
        threshold: 0
    });
    return (() => {
        const _el$ = _tmpl$$z.cloneNode(true);
        const _ref$ = observerReference;
        typeof _ref$ === "function" ? _ref$(_el$) : observerReference = _el$;
        spread(_el$, () => createTestId('general-observer'), false, true);
        insert(_el$, createComponent(Show, {
            get when() {
                return isVisible();
            },
            get fallback() {
                return (() => {
                    const _el$2 = _tmpl$2$1.cloneNode(true);
                    _el$2.style.setProperty("width", "100%");
                    effect(() => _el$2.style.setProperty("height", properties_.height));
                    return _el$2;
                })();
            },
            get children() {
                return properties_.children;
            }
        }));
        return _el$;
    })();
};

const _tmpl$$y = /*#__PURE__*/ template(`<div class="airtable-base-solid-social"><iframe class="airtable-base" width="100%" height="533"></iframe></div>`, 4);
const AirtableBase = properties => {
    const properties_ = mergeProps({
        layout: '',
        viewControls: 'on'
    }, properties);
    return createComponent(GeneralObserver, {
        get children() {
            const _el$ = _tmpl$$y.cloneNode(true), _el$2 = _el$.firstChild;
            _el$.style.setProperty("position", "relative");
            spread(_el$2, () => createTestId('airtable-base'), false, false);
            _el$2.style.setProperty("background", "transparent");
            _el$2.style.setProperty("border", "1px solid #ccc");
            effect(_p$ => {
                const _v$ = `airtable-${properties_.airtableBaseId}`, _v$2 = `//airtable.com/embed/${properties_.airtableBaseId}?backgroundColor=green&${!properties_.layout ? `` : `layout=${properties_.layout}&`}viewControls=${properties_.viewControls}`;
                _v$ !== _p$._v$ && setAttribute(_el$2, "title", _p$._v$ = _v$);
                _v$2 !== _p$._v$2 && setAttribute(_el$2, "src", _p$._v$2 = _v$2);
                return _p$;
            }, {
                _v$: undefined,
                _v$2: undefined
            });
            return _el$;
        }
    });
};

const _tmpl$$x = /*#__PURE__*/ template(`<div class="airtable-form-solid-social"><iframe class="airtable-form" width="100%" height="533"></iframe></div>`, 4);
const AirtableForm = properties => createComponent(GeneralObserver, {
    get children() {
        const _el$ = _tmpl$$x.cloneNode(true), _el$2 = _el$.firstChild;
        _el$.style.setProperty("position", "relative");
        spread(_el$2, () => createTestId('airtable-form'), false, false);
        _el$2.style.setProperty("background", "transparent");
        _el$2.style.setProperty("border", "1px solid #ccc");
        effect(_p$ => {
            const _v$ = `airtable-${properties.airtableFormId}`, _v$2 = `//airtable.com/embed/${properties.airtableFormId}?backgroundColor=green`;
            _v$ !== _p$._v$ && setAttribute(_el$2, "title", _p$._v$ = _v$);
            _v$2 !== _p$._v$2 && setAttribute(_el$2, "src", _p$._v$2 = _v$2);
            return _p$;
        }, {
            _v$: undefined,
            _v$2: undefined
        });
        return _el$;
    }
});

const _tmpl$$w = /*#__PURE__*/ template(`<div class="buzzsprout-solid-social"><iframe class="buzzsprout" scrolling="no"></iframe></div>`, 4);
const Buzzsprout = properties => {
    const properties_ = mergeProps({
        width: '100%',
        height: '200'
    }, properties);
    return createComponent(Show, {
        get when() {
            return /^\d{7}\/\d{7}-[\W\w]+/.test(properties_.buzzsproutId);
        },
        get children() {
            return createComponent(GeneralObserver, {
                get children() {
                    const _el$ = _tmpl$$w.cloneNode(true), _el$2 = _el$.firstChild;
                    _el$.style.setProperty("position", "relative");
                    spread(_el$2, () => createTestId('buzzsprout'), false, false);
                    effect(_p$ => {
                        const _v$ = `buzzsprout-${properties_.buzzsproutId}`, _v$2 = `//www.buzzsprout.com/${properties_.buzzsproutId}?client_source=small_player&amp;iframe=true`, _v$3 = properties_.width, _v$4 = properties_.height;
                        _v$ !== _p$._v$ && setAttribute(_el$2, "title", _p$._v$ = _v$);
                        _v$2 !== _p$._v$2 && setAttribute(_el$2, "src", _p$._v$2 = _v$2);
                        _v$3 !== _p$._v$3 && setAttribute(_el$2, "width", _p$._v$3 = _v$3);
                        _v$4 !== _p$._v$4 && setAttribute(_el$2, "height", _p$._v$4 = _v$4);
                        return _p$;
                    }, {
                        _v$: undefined,
                        _v$2: undefined,
                        _v$3: undefined,
                        _v$4: undefined
                    });
                    return _el$;
                }
            });
        }
    });
};

const _tmpl$$v = /*#__PURE__*/ template(`<div class="cinnamon-solid-social"><iframe class="cinnamon" allow="monetization; accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe></div>`, 4);
const Cinnamon = properties => createComponent(GeneralObserver, {
    get children() {
        const _el$ = _tmpl$$v.cloneNode(true), _el$2 = _el$.firstChild;
        spread(_el$2, () => createTestId('cinnamon'), false, false);
        _el$2.style.setProperty("position", "absolute");
        _el$2.style.setProperty("top", "0");
        _el$2.style.setProperty("left", "0");
        _el$2.style.setProperty("width", "100%");
        _el$2.style.setProperty("height", "100%");
        effect(_p$ => {
            const _v$ = {
                position: 'relative',
                width: '100%',
                ...getPadding$1('16:9')
            }, _v$2 = `cinnamon-${properties.cinnamonId}`, _v$3 = `//cinnamon.video/embed?v=${properties.cinnamonId}`;
            _p$._v$ = style(_el$, _v$, _p$._v$);
            _v$2 !== _p$._v$2 && setAttribute(_el$2, "title", _p$._v$2 = _v$2);
            _v$3 !== _p$._v$3 && setAttribute(_el$2, "src", _p$._v$3 = _v$3);
            return _p$;
        }, {
            _v$: undefined,
            _v$2: undefined,
            _v$3: undefined
        });
        return _el$;
    }
});

const _tmpl$$u = /*#__PURE__*/ template(`<iframe class="codepen" allowfullscreen></iframe>`, 2);
const CodePen = properties => {
    const properties_ = mergeProps({
        height: 500,
        tabs: 'result',
        clickToLoad: false,
        editable: false,
        theme: 'default'
    }, properties);
    return createComponent(GeneralObserver, {
        get height() {
            return properties_.height;
        },
        get children() {
            const _el$ = _tmpl$$u.cloneNode(true);
            spread(_el$, () => createTestId('codepen'), false, false);
            _el$.style.setProperty("width", "100%");
            effect(_p$ => {
                const _v$ = `codepen-${properties_.codePenId}`, _v$2 = properties_.height, _v$3 = `//codepen.io/team/codepen/embed${properties_.clickToLoad ? '/preview' : ''}/${properties_.codePenId}?height=265&theme-id=${properties_.theme}&default-tab=${properties_.tabs}${properties_.editable ? '&editable=true' : ''}`;
                _v$ !== _p$._v$ && setAttribute(_el$, "title", _p$._v$ = _v$);
                _v$2 !== _p$._v$2 && setAttribute(_el$, "height", _p$._v$2 = _v$2);
                _v$3 !== _p$._v$3 && setAttribute(_el$, "src", _p$._v$3 = _v$3);
                return _p$;
            }, {
                _v$: undefined,
                _v$2: undefined,
                _v$3: undefined
            });
            return _el$;
        }
    });
};

const _tmpl$$t = /*#__PURE__*/ template(`<iframe class="codesandbox" allow="geolocation; microphone; camera; midi; vr; accelerometer; gyroscope; payment; ambient-light-sensor; encrypted-media; usb" sandbox="allow-modals allow-forms allow-popups allow-scripts allow-same-origin"></iframe>`, 2);
const CodeSandbox = properties => createComponent(GeneralObserver, {
    get children() {
        const _el$ = _tmpl$$t.cloneNode(true);
        spread(_el$, () => createTestId('codesandbox'), false, false);
        _el$.style.setProperty("width", "100%");
        _el$.style.setProperty("height", "500px");
        _el$.style.setProperty("border", "0");
        _el$.style.setProperty("borderRadius", "4px");
        _el$.style.setProperty("overflow", "hidden");
        effect(_p$ => {
            const _v$ = `codeSandbox-${properties.codeSandboxId}`, _v$2 = `//codesandbox.io/embed/${properties.codeSandboxId}`;
            _v$ !== _p$._v$ && setAttribute(_el$, "title", _p$._v$ = _v$);
            _v$2 !== _p$._v$2 && setAttribute(_el$, "src", _p$._v$2 = _v$2);
            return _p$;
        }, {
            _v$: undefined,
            _v$2: undefined
        });
        return _el$;
    }
});

const _tmpl$$s = /*#__PURE__*/ template(`<div class="egghead-lesson-solid-social"><iframe class="egghead-lesson" allow="autoplay; fullscreen"></iframe></div>`, 4);
const EggheadLesson = properties => createComponent(GeneralObserver, {
    get children() {
        const _el$ = _tmpl$$s.cloneNode(true), _el$2 = _el$.firstChild;
        spread(_el$2, () => createTestId('egghead-lesson'), false, false);
        _el$2.style.setProperty("position", "absolute");
        _el$2.style.setProperty("top", "0");
        _el$2.style.setProperty("left", "0");
        _el$2.style.setProperty("width", "100%");
        _el$2.style.setProperty("height", "100%");
        effect(_p$ => {
            const _v$ = {
                position: 'relative',
                width: '100%',
                ...getPadding$1('16:9')
            }, _v$2 = `egghead-${properties.lessonId}`, _v$3 = `//egghead.io/lessons/${properties.lessonId}/embed`;
            _p$._v$ = style(_el$, _v$, _p$._v$);
            _v$2 !== _p$._v$2 && setAttribute(_el$2, "title", _p$._v$2 = _v$2);
            _v$3 !== _p$._v$3 && setAttribute(_el$2, "src", _p$._v$3 = _v$3);
            return _p$;
        }, {
            _v$: undefined,
            _v$2: undefined,
            _v$3: undefined
        });
        return _el$;
    }
});

const _tmpl$$r = /*#__PURE__*/ template(`<iframe class="figma" allowfullscreen></iframe>`, 2);
const Figma = properties => {
    const properties_ = mergeProps({
        height: 450
    }, properties);
    const regex = /(file|proto)\/([\dA-Za-z]{22,128})(?:\/.*)?$/;
    return createComponent(Show, {
        get when() {
            return regex.test(properties_.url);
        },
        get children() {
            return createComponent(GeneralObserver, {
                get height() {
                    return properties_.height;
                },
                get children() {
                    const _el$ = _tmpl$$r.cloneNode(true);
                    spread(_el$, () => createTestId('figma'), false, false);
                    _el$.style.setProperty("width", "100%");
                    effect(_p$ => {
                        const _v$ = `figma-${properties_.title}`, _v$2 = properties_.height, _v$3 = `//www.figma.com/embed?embed_host=mdx-embed&url=https://www.figma.com/${properties_.url}`;
                        _v$ !== _p$._v$ && setAttribute(_el$, "title", _p$._v$ = _v$);
                        _v$2 !== _p$._v$2 && setAttribute(_el$, "height", _p$._v$2 = _v$2);
                        _v$3 !== _p$._v$3 && setAttribute(_el$, "src", _p$._v$3 = _v$3);
                        return _p$;
                    }, {
                        _v$: undefined,
                        _v$2: undefined,
                        _v$3: undefined
                    });
                    return _el$;
                }
            });
        }
    });
};

// src/index.ts
var createScriptLoader = (opts) => {
  const script = document.createElement("script");
  opts.type && (script.type = opts.type);
  opts.onload && script.addEventListener("load", opts.onload);
  opts.onerror && script.addEventListener("error", opts.onerror);
  const remove = () => document.head.contains(script) && document.head.removeChild(script);
  const load = () => {
    const src = typeof opts.src === "string" ? opts.src : opts.src();
    const prop = /^(https?:|\w[\.\w-_%]+|)\//.test(src) ? "src" : "textContent";
    if (script[prop] !== src) {
      script[prop] = src;
      document.head.appendChild(script);
    }
  };
  load();
  createEffect(load, false);
  onCleanup(remove);
  return [script, remove];
};

let isFlickrScriptAdded = false;
const flickrClasses = ['.flickr-solid-social'].join(',');
const flickrEmbedUrl = '//embedr.flickr.com/assets/client-code.js';
const handleFlickrLoad = () => {
    if (document.querySelector(flickrClasses) && !isFlickrScriptAdded)
        createScriptLoader({
            src: flickrEmbedUrl,
            onload: () => isFlickrScriptAdded = true
        });
};

const _tmpl$$q = /*#__PURE__*/ template(`<span class="flickr" data-flickr-embed="true" data-header="true" data-footer="true"><img width="100%" height="auto"></span>`, 3);
const Flickr = properties => createComponent(GeneralObserver, {
    onEnter: handleFlickrLoad,
    get children() {
        const _el$ = _tmpl$$q.cloneNode(true), _el$2 = _el$.firstChild;
        spread(_el$, () => createTestId('flickr'), false, true);
        effect(_p$ => {
            const _v$ = `//live.staticflickr.com/${properties.flickrLink}`, _v$2 = properties.flickrLink;
            _v$ !== _p$._v$ && setAttribute(_el$2, "src", _p$._v$ = _v$);
            _v$2 !== _p$._v$2 && setAttribute(_el$2, "alt", _p$._v$2 = _v$2);
            return _p$;
        }, {
            _v$: undefined,
            _v$2: undefined
        });
        return _el$;
    }
});

const _tmpl$$p = /*#__PURE__*/ template(`<div class="gist"></div>`, 2);
const Gist = properties => {
    const [gistResponse, setGistResponse] = createStore({
        gist: {
            isLoading: true,
            div: '',
            file: ''
        }
    });
    const gistId = properties.gistLink.split('/')[1];
    const gistEmbedScript = `//gist.github.com/${properties.gistLink}.json?callback=gist_callback_${gistId}`;
    onMount(() => {
        // eslint-disable-next-line @typescript-eslint/ban-ts-comment
        // @ts-ignore
        window[`gist_callback_${gistId}`] = gist => {
            createStyleSheet(gist.stylesheet);
            setGistResponse({
                gist: {
                    isLoading: false,
                    div: gist.div,
                    file: gist.files[0]
                }
            });
        };
        createScriptLoader({
            src: gistEmbedScript
        });
    });
    return createComponent(GeneralObserver, {
        get children() {
            return createComponent(Show, {
                get when() {
                    return !gistResponse.gist.isLoading;
                },
                get children() {
                    const _el$ = _tmpl$$p.cloneNode(true);
                    spread(_el$, () => createTestId('gist'), false, false);
                    effect(() => _el$.innerHTML = gistResponse.gist.div);
                    return _el$;
                }
            });
        }
    });
};

const instgrmClasses = [".instagram-media", ".instagram-media-rendered"].join(",");
const instgrmProcess = () => window.instgrm?.Embeds.process();
const handleInstagrmLoad = () => {
    if (document.querySelector(instgrmClasses) && !window.instgrm) {
        createScriptLoader({ src: "//www.instagram.com/embed.js" });
        return;
    }
    instgrmProcess();
};

const _tmpl$$o = /*#__PURE__*/ template(`<blockquote class="instagram-media instagram-solid-social" data-instgrm-version="12"><a></a></blockquote>`, 4);
const Instagram = properties => createComponent(GeneralObserver, {
    onEnter: handleInstagrmLoad,
    get children() {
        const _el$ = _tmpl$$o.cloneNode(true), _el$2 = _el$.firstChild;
        spread(_el$, () => createTestId('instagram'), false, true);
        insert(_el$2, () => window.instgrm && '');
        effect(() => setAttribute(_el$2, "href", `//instagram.com/p/${properties.instagramId}`));
        return _el$;
    }
});

const _tmpl$$n = /*#__PURE__*/ template(`<div class="lbry-solid-social"><iframe class="lbry" allow="fullscreen"></iframe></div>`, 4);
const Lbry = properties => {
    const properties_ = mergeProps({
        skipTo: {
            s: 0
        }
    }, properties);
    return createComponent(GeneralObserver, {
        get children() {
            const _el$ = _tmpl$$n.cloneNode(true), _el$2 = _el$.firstChild;
            spread(_el$2, () => createTestId('lbry'), false, false);
            _el$2.style.setProperty("position", "absolute");
            _el$2.style.setProperty("top", "0");
            _el$2.style.setProperty("left", "0");
            _el$2.style.setProperty("width", "100%");
            _el$2.style.setProperty("height", "100%");
            effect(_p$ => {
                const _v$ = {
                    position: 'relative',
                    width: '100%',
                    ...getPadding$1('16:9')
                }, _v$2 = `lbry-${properties_.lbryId}`, _v$3 = `//lbry.tv/$/embed/${properties_.lbryId}?t=${properties_.skipTo.s}`;
                _p$._v$ = style(_el$, _v$, _p$._v$);
                _v$2 !== _p$._v$2 && setAttribute(_el$2, "title", _p$._v$2 = _v$2);
                _v$3 !== _p$._v$3 && setAttribute(_el$2, "src", _p$._v$3 = _v$3);
                return _p$;
            }, {
                _v$: undefined,
                _v$2: undefined,
                _v$3: undefined
            });
            return _el$;
        }
    });
};

const linkedInClasses = [".LI-profile-badge", ".LI-simple-link"].join(",");
const linkedInBadgesUrl = "//platform.linkedin.com/badges/js/profile.js";
const LIRenderAll = () => window.LI && typeof window.LIRenderAll === "function" && window.LIRenderAll();
const handleLinkedInLoad = () => {
    if (document.querySelector(linkedInClasses) && !(window.LI && window.LIRenderAll)) {
        createScriptLoader({ src: linkedInBadgesUrl });
        return;
    }
    LIRenderAll();
};

const _tmpl$$m = /*#__PURE__*/ template(`<div class="LI-profile-badge linkedin-badge" data-version="v1"><a class="LI-simple-link">Loading</a></div>`, 4);
const LinkedInBadge = properties => {
    const properties_ = mergeProps({
        badgeType: 'vertical',
        badgeSize: 'medium',
        theme: 'light',
        locale: 'en_US'
    }, properties);
    return createComponent(GeneralObserver, {
        onEnter: handleLinkedInLoad,
        get children() {
            const _el$ = _tmpl$$m.cloneNode(true), _el$2 = _el$.firstChild;
            spread(_el$, () => createTestId('linkedin-badge'), false, true);
            effect(_p$ => {
                const _v$ = properties_.badgeSize, _v$2 = properties_.locale, _v$3 = properties_.badgeType, _v$4 = properties_.theme, _v$5 = properties_.username, _v$6 = `//uk.linkedin.com/in/${properties_.username}?trk=profile-badge`;
                _v$ !== _p$._v$ && setAttribute(_el$, "data-size", _p$._v$ = _v$);
                _v$2 !== _p$._v$2 && setAttribute(_el$, "data-locale", _p$._v$2 = _v$2);
                _v$3 !== _p$._v$3 && setAttribute(_el$, "data-type", _p$._v$3 = _v$3);
                _v$4 !== _p$._v$4 && setAttribute(_el$, "data-theme", _p$._v$4 = _v$4);
                _v$5 !== _p$._v$5 && setAttribute(_el$, "data-vanity", _p$._v$5 = _v$5);
                _v$6 !== _p$._v$6 && setAttribute(_el$2, "href", _p$._v$6 = _v$6);
                return _p$;
            }, {
                _v$: undefined,
                _v$2: undefined,
                _v$3: undefined,
                _v$4: undefined,
                _v$5: undefined,
                _v$6: undefined
            });
            return _el$;
        }
    });
};

const _tmpl$$l = /*#__PURE__*/ template(`<div class="listennotes-episode-solid-social"><iframe class="listennotes-episode" frameborder="0" scrolling="no" loading="lazy"></iframe></div>`, 4);
const ListenNotesEpisode = properties => {
    const properties_ = mergeProps({
        width: '100%',
        height: '180px'
    }, properties);
    return createComponent(GeneralObserver, {
        get children() {
            const _el$ = _tmpl$$l.cloneNode(true), _el$2 = _el$.firstChild;
            _el$.style.setProperty("position", "relative");
            spread(_el$2, () => createTestId('listennotes-episode'), false, false);
            _el$2.style.setProperty("position", "absolute");
            _el$2.style.setProperty("top", "0");
            _el$2.style.setProperty("left", "0");
            _el$2.style.setProperty("width", "100%");
            _el$2.style.setProperty("height", "100%");
            effect(_p$ => {
                const _v$ = properties_.height, _v$2 = properties_.width, _v$3 = `listennotes-${properties.episodeId}`, _v$4 = `//www.listennotes.com/podcasts/${properties.episodeId}/embed/`;
                _v$ !== _p$._v$ && _el$.style.setProperty("height", _p$._v$ = _v$);
                _v$2 !== _p$._v$2 && _el$.style.setProperty("width", _p$._v$2 = _v$2);
                _v$3 !== _p$._v$3 && setAttribute(_el$2, "title", _p$._v$3 = _v$3);
                _v$4 !== _p$._v$4 && setAttribute(_el$2, "src", _p$._v$4 = _v$4);
                return _p$;
            }, {
                _v$: undefined,
                _v$2: undefined,
                _v$3: undefined,
                _v$4: undefined
            });
            return _el$;
        }
    });
};

const pinterestClasses = ["pinterest-pin", "pinterest-board", "pinterest-follow-button"].map((pinClass) => `.${pinClass}`).join(",");
const pinterestEmbedScript = '!function(a,b,c){var d,e,f;d="PIN_"+~~((new Date).getTime()/864e5),a[d]?a[d]+=1:(a[d]=1,a.setTimeout(function(){e=b.getElementsByTagName("SCRIPT")[0],f=b.createElement("SCRIPT"),f.type="text/javascript",f.async=!0,f.src=c.mainUrl+"?"+Math.random(),e.parentNode.insertBefore(f,e)},10))}(window,document,{mainUrl:"//assets.pinterest.com/js/pinit_main.js"});';
const handlePinterestBuild = () => {
    if (document.querySelector(pinterestClasses) && !window.PinUtils) {
        createScriptLoader({ src: pinterestEmbedScript });
        return;
    }
    window.PinUtils?.build();
};

const _tmpl$$k = /*#__PURE__*/ template(`<a class="pinterest-pin" data-pin-do="embedPin"></a>`, 2);
const Pin = properties => {
    const properties_ = mergeProps({
        size: 'small'
    }, properties);
    return createComponent(GeneralObserver, {
        onEnter: handlePinterestBuild,
        get children() {
            const _el$ = _tmpl$$k.cloneNode(true);
            spread(_el$, () => createTestId('pin'), false, false);
            effect(_p$ => {
                const _v$ = properties_.size, _v$2 = `//www.pinterest.com/pin/${properties_.pinId}`;
                _v$ !== _p$._v$ && setAttribute(_el$, "data-pin-width", _p$._v$ = _v$);
                _v$2 !== _p$._v$2 && setAttribute(_el$, "href", _p$._v$2 = _v$2);
                return _p$;
            }, {
                _v$: undefined,
                _v$2: undefined
            });
            return _el$;
        }
    });
};

const _tmpl$$j = /*#__PURE__*/ template(`<a class="pinterest-board"></a>`, 2);
const PinterestBoard = properties => {
    const properties_ = mergeProps({
        width: 400,
        height: 250,
        imageWidth: 80,
        variant: 'board'
    }, properties);
    return createComponent(GeneralObserver, {
        onEnter: handlePinterestBuild,
        get children() {
            const _el$ = _tmpl$$j.cloneNode(true);
            spread(_el$, () => createTestId('pinterest-board'), false, false);
            effect(_p$ => {
                const _v$ = `embed${properties_.variant.charAt(0).toUpperCase()}${properties_.variant.slice(1)}`, _v$2 = properties_.width, _v$3 = properties_.height, _v$4 = properties_.imageWidth, _v$5 = `//www.pinterest.com/${properties_.pinterestLink}`;
                _v$ !== _p$._v$ && setAttribute(_el$, "data-pin-do", _p$._v$ = _v$);
                _v$2 !== _p$._v$2 && setAttribute(_el$, "data-pin-board-width", _p$._v$2 = _v$2);
                _v$3 !== _p$._v$3 && setAttribute(_el$, "data-pin-scale-height", _p$._v$3 = _v$3);
                _v$4 !== _p$._v$4 && setAttribute(_el$, "data-pin-scale-width", _p$._v$4 = _v$4);
                _v$5 !== _p$._v$5 && setAttribute(_el$, "href", _p$._v$5 = _v$5);
                return _p$;
            }, {
                _v$: undefined,
                _v$2: undefined,
                _v$3: undefined,
                _v$4: undefined,
                _v$5: undefined
            });
            return _el$;
        }
    });
};

const _tmpl$$i = /*#__PURE__*/ template(`<a class="pinterest-follow-button" data-pin-do="buttonFollow"></a>`, 2);
const PinterestFollowButton = properties => createComponent(GeneralObserver, {
    onEnter: handlePinterestBuild,
    get children() {
        const _el$ = _tmpl$$i.cloneNode(true);
        spread(_el$, () => createTestId('pinterest-follow-button'), false, true);
        insert(_el$, () => `Follow @${properties.username}`);
        effect(() => setAttribute(_el$, "href", `//www.pinterest.com/${properties.username}/`));
        return _el$;
    }
});

const _tmpl$$h = /*#__PURE__*/ template(`<div class="simplecast-episode-solid-social"><iframe class="simplecast-episode" seamless></iframe></div>`, 4);
const SimplecastEpisode = properties => {
    const properties_ = mergeProps({
        theme: `light`
    }, properties);
    return createComponent(GeneralObserver, {
        get children() {
            const _el$ = _tmpl$$h.cloneNode(true), _el$2 = _el$.firstChild;
            _el$.style.setProperty("position", "relative");
            _el$.style.setProperty("height", "200px");
            _el$.style.setProperty("width", "100%");
            spread(_el$2, () => createTestId('simplecast-episode'), false, false);
            _el$2.style.setProperty("position", "absolute");
            _el$2.style.setProperty("top", "0");
            _el$2.style.setProperty("left", "0");
            _el$2.style.setProperty("width", "100%");
            _el$2.style.setProperty("height", "100%");
            effect(_p$ => {
                const _v$ = `simplecast-${properties_.episodeId}`, _v$2 = `//player.simplecast.com/${properties_.episodeId}${properties_.theme === `dark` ? `?dark=true` : ``}`;
                _v$ !== _p$._v$ && setAttribute(_el$2, "title", _p$._v$ = _v$);
                _v$2 !== _p$._v$2 && setAttribute(_el$2, "src", _p$._v$2 = _v$2);
                return _p$;
            }, {
                _v$: undefined,
                _v$2: undefined
            });
            return _el$;
        }
    });
};

const _tmpl$$g = /*#__PURE__*/ template(`<div class="snack-solid-social" data-snack-preview="true"></div>`, 2);
const scriptUrl = '//snack.expo.io/embed.js';
const Snack = properties => {
    const properties_ = mergeProps({
        platform: 'web',
        theme: 'light'
    }, properties);
    return createComponent(GeneralObserver, {
        onEnter: () => createScriptLoader({
            src: scriptUrl
        }),
        get children() {
            const _el$ = _tmpl$$g.cloneNode(true);
            spread(_el$, () => createTestId('snack'), false, false);
            _el$.style.setProperty("overflow", "hidden");
            _el$.style.setProperty("background", "#F9F9F9");
            _el$.style.setProperty("border", "1px solid var(--color-border)");
            _el$.style.setProperty("borderRadius", "4px");
            _el$.style.setProperty("height", "505px");
            _el$.style.setProperty("width", "100%");
            effect(_p$ => {
                const _v$ = properties_.snackId, _v$2 = properties_.platform, _v$3 = properties_.theme;
                _v$ !== _p$._v$ && setAttribute(_el$, "data-snack-id", _p$._v$ = _v$);
                _v$2 !== _p$._v$2 && setAttribute(_el$, "data-snack-platform", _p$._v$2 = _v$2);
                _v$3 !== _p$._v$3 && setAttribute(_el$, "data-snack-theme", _p$._v$3 = _v$3);
                return _p$;
            }, {
                _v$: undefined,
                _v$2: undefined,
                _v$3: undefined
            });
            return _el$;
        }
    });
};

const _tmpl$$f = /*#__PURE__*/ template(`<iframe class="soundcloud" allow="autoplay"></iframe>`, 2);
const SoundCloud = properties => {
    const properties_ = mergeProps({
        width: '100%',
        height: 'auto',
        autoPlay: false,
        visual: false,
        color: '23ff00f5'
    }, properties);
    return createComponent(GeneralObserver, {
        get children() {
            const _el$ = _tmpl$$f.cloneNode(true);
            spread(_el$, () => createTestId('soundcloud'), false, false);
            effect(_p$ => {
                const _v$ = `sound-cloud-${properties_.soundCloudLink}`, _v$2 = properties_.width, _v$3 = properties_.height, _v$4 = `//w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/${properties_.soundCloudLink}&color=%23${properties_.color}&auto_play=${properties_.autoPlay.toString()}&visual=${properties_.visual.toString()}`;
                _v$ !== _p$._v$ && setAttribute(_el$, "title", _p$._v$ = _v$);
                _v$2 !== _p$._v$2 && setAttribute(_el$, "width", _p$._v$2 = _v$2);
                _v$3 !== _p$._v$3 && setAttribute(_el$, "height", _p$._v$3 = _v$3);
                _v$4 !== _p$._v$4 && setAttribute(_el$, "src", _p$._v$4 = _v$4);
                return _p$;
            }, {
                _v$: undefined,
                _v$2: undefined,
                _v$3: undefined,
                _v$4: undefined
            });
            return _el$;
        }
    });
};

const _tmpl$$e = /*#__PURE__*/ template(`<iframe class="spotify" allow="encrypted-media"></iframe>`, 2);
const Spotify = properties => {
    const properties_ = mergeProps({
        width: 320,
        height: 380
    }, properties);
    return createComponent(GeneralObserver, {
        get children() {
            const _el$ = _tmpl$$e.cloneNode(true);
            spread(_el$, () => createTestId('spotify'), false, false);
            effect(_p$ => {
                const _v$ = `spotify-${properties_.spotifyLink}`, _v$2 = `//open.spotify.com/embed/${properties.spotifyLink}`, _v$3 = properties_.width, _v$4 = properties_.height;
                _v$ !== _p$._v$ && setAttribute(_el$, "title", _p$._v$ = _v$);
                _v$2 !== _p$._v$2 && setAttribute(_el$, "src", _p$._v$2 = _v$2);
                _v$3 !== _p$._v$3 && setAttribute(_el$, "width", _p$._v$3 = _v$3);
                _v$4 !== _p$._v$4 && setAttribute(_el$, "height", _p$._v$4 = _v$4);
                return _p$;
            }, {
                _v$: undefined,
                _v$2: undefined,
                _v$3: undefined,
                _v$4: undefined
            });
            return _el$;
        }
    });
};

const _tmpl$$d = /*#__PURE__*/ template(`<div class="strava-solid-social"><iframe class="strava" height="100%" width="100%"></iframe></div>`, 4);
const Strava = properties => createComponent(GeneralObserver, {
    get children() {
        const _el$ = _tmpl$$d.cloneNode(true), _el$2 = _el$.firstChild;
        spread(_el$, () => createTestId('strava'), false, true);
        _el$.style.setProperty("position", "relative");
        _el$.style.setProperty("height", "350px");
        _el$.style.setProperty("maxWidth", "568px");
        _el$.style.setProperty("width", "100%");
        _el$.style.setProperty("overflow", "auto");
        _el$2.style.setProperty("minWidth", "380px");
        effect(_p$ => {
            const _v$ = `strava-${properties.activityId}`, _v$2 = `//www.strava.com/activities/${properties.activityId}`;
            _v$ !== _p$._v$ && setAttribute(_el$2, "title", _p$._v$ = _v$);
            _v$2 !== _p$._v$2 && setAttribute(_el$2, "src", _p$._v$2 = _v$2);
            return _p$;
        }, {
            _v$: undefined,
            _v$2: undefined
        });
        return _el$;
    }
});

const handleTikTokLoad = () => {
    if (document.querySelector(".tiktok") && !window.tiktok)
        createScriptLoader({ src: "//www.tiktok.com/embed.js" });
};

const _tmpl$$c = /*#__PURE__*/ template(`<blockquote class="tiktok"><section><a></a></section></blockquote>`, 6);
const TikTok = properties => createComponent(GeneralObserver, {
    onEnter: handleTikTokLoad,
    get children() {
        const _el$ = _tmpl$$c.cloneNode(true), _el$2 = _el$.firstChild, _el$3 = _el$2.firstChild;
        spread(_el$, () => createTestId('tiktok'), false, true);
        insert(_el$3, () => !window.tiktok && '');
        effect(_p$ => {
            const _v$ = `//www.tiktok.com/${properties.tikTokId}`, _v$2 = properties.tikTokId.split('/').pop(), _v$3 = `//tiktok.com/${properties.tikTokId}`;
            _v$ !== _p$._v$ && setAttribute(_el$, "cite", _p$._v$ = _v$);
            _v$2 !== _p$._v$2 && setAttribute(_el$, "data-video-id", _p$._v$2 = _v$2);
            _v$3 !== _p$._v$3 && setAttribute(_el$3, "href", _p$._v$3 = _v$3);
            return _p$;
        }, {
            _v$: undefined,
            _v$2: undefined,
            _v$3: undefined
        });
        return _el$;
    }
});

function constructTwitchURL(twitchId, channel, collection, baseUrl) {
    const sourceBlocks = [baseUrl];
    if (twitchId) {
        sourceBlocks.push(`&video=v${twitchId}`);
    }
    else if (channel) {
        sourceBlocks.push(`&channel=${channel}`);
    }
    else if (collection) {
        sourceBlocks.push(`&collection=${collection}`);
    }
    return sourceBlocks.join("");
}

const _tmpl$$b = /*#__PURE__*/ template(`<div class="twitch-solid-social"><iframe class="twitch" allow="autoplay; fullscreen"></iframe></div>`, 4);
const Twitch = properties => {
    const properties_ = mergeProps({
        parent: 'localhost',
        autoPlay: false,
        skipTo: {
            h: 0,
            m: 0,
            s: 0
        },
        channel: '',
        collection: ''
    }, properties);
    const title = properties_.twitchId ? `twitch-${properties_.twitchId}` : `twitch`;
    const baseUrl = `//player.twitch.tv/?autoplay=${properties_.autoPlay.toString()}&t=${properties_.skipTo.h}h${properties_.skipTo.m}m${properties_.skipTo.s}s&parent=${properties_.parent}`;
    const constructedSourceURL = constructTwitchURL(properties_.twitchId, properties_.channel, properties_.collection, baseUrl);
    return createComponent(GeneralObserver, {
        get children() {
            const _el$ = _tmpl$$b.cloneNode(true), _el$2 = _el$.firstChild;
            spread(_el$, () => createTestId('twitch'), false, true);
            setAttribute(_el$2, "title", title);
            setAttribute(_el$2, "src", constructedSourceURL);
            _el$2.style.setProperty("position", "absolute");
            _el$2.style.setProperty("top", "0");
            _el$2.style.setProperty("left", "0");
            _el$2.style.setProperty("width", "100%");
            _el$2.style.setProperty("height", "100%");
            effect(_$p => style(_el$, {
                position: 'relative',
                width: '100%',
                ...getPadding$1('16:9')
            }, _$p));
            return _el$;
        }
    });
};

const twttrClasses = [
    "twitter-tweet",
    "twitter-follow-button",
    "twitter-hashtag-button",
    "twitter-list",
    "twitter-mention-button",
    "twitter-timeline"
].map((twttrClass) => `.${twttrClass}`).join(",");
const twttrLoad = () => document.querySelectorAll(twttrClasses).forEach((element) => void window.twttr?.widgets?.load?.(element));
const handleTwttrLoad = () => {
    if (document.querySelector(twttrClasses) && !window.twttr) {
        createScriptLoader({ src: "//platform.twitter.com/widgets.js" });
        return;
    }
    twttrLoad();
};
const handleTwttrUpdate = (targetElement, { theme }) => {
    const tweet = document.querySelector(targetElement);
    const source = tweet?.getAttribute("src");
    if (source)
        tweet?.setAttribute("src", source.replace(/theme=.*?&/, `theme=${theme}&`));
};

const _tmpl$$a = /*#__PURE__*/ template(`<div class="twitter-solid-social"><blockquote class="twitter-tweet"><a></a></blockquote></div>`, 6);
const Tweet = properties => {
    const properties_ = mergeProps({
        theme: 'light',
        align: 'left',
        hideConversation: false
    }, properties);
    const tweetLinkSplit = properties_.tweetLink.split('/');
    const tweetId = tweetLinkSplit[tweetLinkSplit.length - 1];
    createEffect(on(() => [properties_.align, properties_.theme, properties_.hideConversation, properties_.tweetLink], () => handleTwttrUpdate(`iframe[data-tweet-id="${tweetId}"]`, properties_), {
        defer: true
    }));
    return createComponent(GeneralObserver, {
        onEnter: handleTwttrLoad,
        get children() {
            const _el$ = _tmpl$$a.cloneNode(true), _el$2 = _el$.firstChild, _el$3 = _el$2.firstChild;
            spread(_el$, () => createTestId('twitter-tweet'), false, true);
            setAttribute(_el$, "id", `twitter-tweet-${tweetId}`);
            _el$.style.setProperty("overflow", "auto");
            insert(_el$3, () => window.twttr && '');
            effect(_p$ => {
                const _v$ = properties_.theme, _v$2 = properties_.align, _v$3 = properties_.hideConversation ? 'none' : '', _v$4 = `//twitter.com/${properties_.tweetLink}?ref_src=twsrc%5Etfw`;
                _v$ !== _p$._v$ && setAttribute(_el$2, "data-theme", _p$._v$ = _v$);
                _v$2 !== _p$._v$2 && setAttribute(_el$2, "data-align", _p$._v$2 = _v$2);
                _v$3 !== _p$._v$3 && setAttribute(_el$2, "data-conversation", _p$._v$3 = _v$3);
                _v$4 !== _p$._v$4 && setAttribute(_el$3, "href", _p$._v$4 = _v$4);
                return _p$;
            }, {
                _v$: undefined,
                _v$2: undefined,
                _v$3: undefined,
                _v$4: undefined
            });
            return _el$;
        }
    });
};

const _tmpl$$9 = /*#__PURE__*/ template(`<a class="twitter-follow-button"></a>`, 2);
const TwitterFollowButton = properties => {
    const properties_ = mergeProps({
        showFollowers: false,
        showUsername: true,
        size: 'small'
    }, properties);
    return createComponent(GeneralObserver, {
        onEnter: handleTwttrLoad,
        get children() {
            const _el$ = _tmpl$$9.cloneNode(true);
            spread(_el$, () => createTestId('twitter-follow-button'), false, true);
            insert(_el$, () => `Follow @${properties_.username}`);
            effect(_p$ => {
                const _v$ = `//twitter.com/${properties_.username}?ref_src=twsrc%5Etfw`, _v$2 = properties_.showFollowers, _v$3 = properties_.showUsername, _v$4 = properties_.size;
                _v$ !== _p$._v$ && setAttribute(_el$, "href", _p$._v$ = _v$);
                _v$2 !== _p$._v$2 && setAttribute(_el$, "data-show-count", _p$._v$2 = _v$2);
                _v$3 !== _p$._v$3 && setAttribute(_el$, "data-show-screen-name", _p$._v$3 = _v$3);
                _v$4 !== _p$._v$4 && setAttribute(_el$, "data-size", _p$._v$4 = _v$4);
                return _p$;
            }, {
                _v$: undefined,
                _v$2: undefined,
                _v$3: undefined,
                _v$4: undefined
            });
            return _el$;
        }
    });
};

const _tmpl$$8 = /*#__PURE__*/ template(`<a class="twitter-hashtag-button"></a>`, 2);
const TwitterHashtagButton = properties => {
    const properties_ = mergeProps({
        size: 'small'
    }, properties);
    return createComponent(GeneralObserver, {
        onEnter: handleTwttrLoad,
        get children() {
            const _el$ = _tmpl$$8.cloneNode(true);
            spread(_el$, () => createTestId('twitter-hashtag-button'), false, true);
            insert(_el$, () => `Tweet #${properties_.hashtag}`);
            effect(_p$ => {
                const _v$ = `//twitter.com/intent/tweet?button_hashtag=${properties_.hashtag}&ref_src=twsrc%5Etfw`, _v$2 = properties_.size;
                _v$ !== _p$._v$ && setAttribute(_el$, "href", _p$._v$ = _v$);
                _v$2 !== _p$._v$2 && setAttribute(_el$, "data-size", _p$._v$2 = _v$2);
                return _p$;
            }, {
                _v$: undefined,
                _v$2: undefined
            });
            return _el$;
        }
    });
};

const _tmpl$$7 = /*#__PURE__*/ template(`<div class="twitter-solid-social"><a class="twitter-list"></a></div>`, 4);
const TwitterList = properties => {
    const properties_ = mergeProps({
        theme: 'light',
        width: '498px',
        height: undefined
    }, properties);
    return createComponent(GeneralObserver, {
        onEnter: handleTwttrLoad,
        get children() {
            const _el$ = _tmpl$$7.cloneNode(true), _el$2 = _el$.firstChild;
            _el$.style.setProperty("overflow", "auto");
            spread(_el$2, () => createTestId('twitter-list'), false, true);
            insert(_el$2, () => `A Twitter List by @${properties_.username}`);
            effect(_p$ => {
                const _v$ = properties_.theme, _v$2 = properties_.width, _v$3 = properties_.height, _v$4 = `//twitter.com/${properties_.username}/lists/${properties_.listName}?ref_src=twsrc%5Etfw`;
                _v$ !== _p$._v$ && setAttribute(_el$2, "data-theme", _p$._v$ = _v$);
                _v$2 !== _p$._v$2 && setAttribute(_el$2, "data-width", _p$._v$2 = _v$2);
                _v$3 !== _p$._v$3 && setAttribute(_el$2, "data-height", _p$._v$3 = _v$3);
                _v$4 !== _p$._v$4 && setAttribute(_el$2, "href", _p$._v$4 = _v$4);
                return _p$;
            }, {
                _v$: undefined,
                _v$2: undefined,
                _v$3: undefined,
                _v$4: undefined
            });
            return _el$;
        }
    });
};

const _tmpl$$6 = /*#__PURE__*/ template(`<a class="twitter-mention-button"></a>`, 2);
const TwitterMentionButton = properties => {
    const properties_ = mergeProps({
        size: 'small'
    }, properties);
    return createComponent(GeneralObserver, {
        onEnter: handleTwttrLoad,
        get children() {
            const _el$ = _tmpl$$6.cloneNode(true);
            spread(_el$, () => createTestId('twitter-mention-button'), false, true);
            insert(_el$, () => `Tweet to @${properties_.username}`);
            effect(_p$ => {
                const _v$ = `//twitter.com/intent/tweet?screen_name=${properties_.username}&ref_src=twsrc%5Etfw`, _v$2 = properties_.size;
                _v$ !== _p$._v$ && setAttribute(_el$, "href", _p$._v$ = _v$);
                _v$2 !== _p$._v$2 && setAttribute(_el$, "data-size", _p$._v$2 = _v$2);
                return _p$;
            }, {
                _v$: undefined,
                _v$2: undefined
            });
            return _el$;
        }
    });
};

const _tmpl$$5 = /*#__PURE__*/ template(`<div class="twitter-solid-social"><a class="twitter-timeline"></a></div>`, 4);
const TwitterTimeline = properties => {
    const properties_ = mergeProps({
        theme: 'light',
        width: '498px'
    }, properties);
    return createComponent(GeneralObserver, {
        onEnter: handleTwttrLoad,
        get children() {
            const _el$ = _tmpl$$5.cloneNode(true), _el$2 = _el$.firstChild;
            _el$.style.setProperty("overflow", "auto");
            spread(_el$2, () => createTestId('twitter-timeline'), false, true);
            insert(_el$2, () => `Tweets by @${properties_.username}`);
            effect(_p$ => {
                const _v$ = properties_.theme, _v$2 = properties_.width, _v$3 = properties_.height, _v$4 = `//twitter.com/${properties_.username}${properties_.showLikes ? `/likes` : ''}?ref_src=twsrc%5Etfw`;
                _v$ !== _p$._v$ && setAttribute(_el$2, "data-theme", _p$._v$ = _v$);
                _v$2 !== _p$._v$2 && setAttribute(_el$2, "data-width", _p$._v$2 = _v$2);
                _v$3 !== _p$._v$3 && setAttribute(_el$2, "data-height", _p$._v$3 = _v$3);
                _v$4 !== _p$._v$4 && setAttribute(_el$2, "href", _p$._v$4 = _v$4);
                return _p$;
            }, {
                _v$: undefined,
                _v$2: undefined,
                _v$3: undefined,
                _v$4: undefined
            });
            return _el$;
        }
    });
};

const _tmpl$$4 = /*#__PURE__*/ template(`<div class="vimeo-solid-social"><iframe class="vimeo" allow="autoplay; fullscreen"></iframe></div>`, 4);
const Vimeo = properties => {
    const properties_ = mergeProps({
        autoPlay: false,
        skipTo: {
            h: 0,
            m: 0,
            s: 0
        }
    }, properties);
    return createComponent(GeneralObserver, {
        get children() {
            const _el$ = _tmpl$$4.cloneNode(true), _el$2 = _el$.firstChild;
            spread(_el$, () => createTestId('vimeo'), false, true);
            _el$2.style.setProperty("position", "absolute");
            _el$2.style.setProperty("top", "0");
            _el$2.style.setProperty("left", "0");
            _el$2.style.setProperty("width", "100%");
            _el$2.style.setProperty("height", "100%");
            effect(_p$ => {
                const _v$ = {
                    position: 'relative',
                    width: '100%',
                    ...getPadding$1('16:9')
                }, _v$2 = `vimeo-${properties_.vimeoId}`, _v$3 = `//player.vimeo.com/video/${properties_.vimeoId}?autoplay=${properties_.autoPlay.toString()}#t=${properties_.skipTo.h}h${properties_.skipTo.m}m${properties_.skipTo.s}s`;
                _p$._v$ = style(_el$, _v$, _p$._v$);
                _v$2 !== _p$._v$2 && setAttribute(_el$2, "title", _p$._v$2 = _v$2);
                _v$3 !== _p$._v$3 && setAttribute(_el$2, "src", _p$._v$3 = _v$3);
                return _p$;
            }, {
                _v$: undefined,
                _v$2: undefined,
                _v$3: undefined
            });
            return _el$;
        }
    });
};

function getPadding(aspectRatio) {
    const regExp = /^([1-9]\d*):([1-9]\d*)$/;
    const [, width, height] = regExp.exec(aspectRatio) || ["", "1", "1"];
    return {
        paddingTop: `${100 * Number.parseInt(height, 10) / Number.parseInt(width, 10)}%`
    };
}

const _tmpl$$3 = /*#__PURE__*/ template(`<div class="whimsical-solid-social"><iframe class="whimsical" allowfullscreen></iframe></div>`, 4);
const Whimsical = properties => {
    const properties_ = mergeProps({
        aspectRatio: '1:1'
    }, properties);
    return createComponent(GeneralObserver, {
        get children() {
            const _el$ = _tmpl$$3.cloneNode(true), _el$2 = _el$.firstChild;
            spread(_el$, () => createTestId('whimsical'), false, true);
            _el$2.style.setProperty("position", "absolute");
            _el$2.style.setProperty("top", "0");
            _el$2.style.setProperty("left", "0");
            _el$2.style.setProperty("width", "100%");
            _el$2.style.setProperty("height", "100%");
            effect(_p$ => {
                const _v$ = {
                    position: 'relative',
                    width: '100%',
                    ...getPadding(properties_.aspectRatio)
                }, _v$2 = `whimsical-${properties_.diagramId}`, _v$3 = `//whimsical.com/embed/${properties_.diagramId}`;
                _p$._v$ = style(_el$, _v$, _p$._v$);
                _v$2 !== _p$._v$2 && setAttribute(_el$2, "title", _p$._v$2 = _v$2);
                _v$3 !== _p$._v$3 && setAttribute(_el$2, "src", _p$._v$3 = _v$3);
                return _p$;
            }, {
                _v$: undefined,
                _v$2: undefined,
                _v$3: undefined
            });
            return _el$;
        }
    });
};

const _tmpl$$2 = /*#__PURE__*/ template(`<iframe class="wikipedia"></iframe>`, 2), _tmpl$2 = /*#__PURE__*/ template(`<div></div>`, 2);
const Wikipedia = properties => {
    const properties_ = mergeProps({
        height: 600
    }, properties);
    const getWikipediaHtml = async () => {
        const response = await fetch(`//en.wikipedia.org/api/rest_v1/page/html/${properties_.wikipediaLink}`);
        const text = await response.text();
        return text.replace(/<a rel="mw:WikiLink"/g, '<a target="_blank" rel="mw:WikiLink"');
    };
    const [wiki] = createResource(() => properties_.wikipediaLink, getWikipediaHtml);
    return createComponent(GeneralObserver, {
        get children() {
            return createComponent(ErrorBoundary, {
                fallback: error => (() => {
                    const _el$2 = _tmpl$2.cloneNode(true);
                    insert(_el$2, () => String(error));
                    return _el$2;
                })(),
                get children() {
                    return createComponent(Suspense, {
                        fallback: "",
                        get children() {
                            const _el$ = _tmpl$$2.cloneNode(true);
                            spread(_el$, () => createTestId('wikipedia'), false, false);
                            _el$.style.setProperty("width", "100%");
                            effect(_p$ => {
                                const _v$ = properties_.wikipediaLink, _v$2 = typeof properties_.height === 'string' ? properties_.height : `${properties_.height}px`, _v$3 = wiki();
                                _v$ !== _p$._v$ && setAttribute(_el$, "title", _p$._v$ = _v$);
                                _v$2 !== _p$._v$2 && _el$.style.setProperty("min-height", _p$._v$2 = _v$2);
                                _v$3 !== _p$._v$3 && setAttribute(_el$, "srcdoc", _p$._v$3 = _v$3);
                                return _p$;
                            }, {
                                _v$: undefined,
                                _v$2: undefined,
                                _v$3: undefined
                            });
                            return _el$;
                        }
                    });
                }
            });
        }
    });
};

let isWistiaAdded = false;
const embedUrl = `//fast.wistia.net/assets/external/E-v1.js`;
const handleWistiaLoad = () => {
    if (!isWistiaAdded)
        createScriptLoader({ src: embedUrl, onload: () => isWistiaAdded = true });
};

const _tmpl$$1 = /*#__PURE__*/ template(`<div class="wistia-container-solid-social"><iframe class="wistia-solid-social"></iframe></div>`, 4);
const Wistia = properties => {
    const properties_ = mergeProps({
        allowfullscreen: true,
        aspectRatio: '16:9',
        width: '100%',
        height: '100%',
        autoPlay: false
    }, properties);
    return createComponent(GeneralObserver, {
        onEnter: handleWistiaLoad,
        get children() {
            const _el$ = _tmpl$$1.cloneNode(true), _el$2 = _el$.firstChild;
            spread(_el$2, () => createTestId('wistia'), false, false);
            _el$2.style.setProperty("position", "absolute");
            _el$2.style.setProperty("top", "0");
            _el$2.style.setProperty("left", "0");
            effect(_p$ => {
                const _v$ = {
                    position: 'relative',
                    width: '100%',
                    ...getPadding$1(properties_.aspectRatio)
                }, _v$2 = `wistia-${properties_.videoId}`, _v$3 = `//fast.wistia.net/embed/iframe/${properties_.videoId}${properties.autoPlay ? '?autoPlay=true' : ''}`, _v$4 = `autoplay; ${properties_.allowfullscreen ? 'fullscreen' : ''}`, _v$5 = properties_.width, _v$6 = properties_.height;
                _p$._v$ = style(_el$, _v$, _p$._v$);
                _v$2 !== _p$._v$2 && setAttribute(_el$2, "title", _p$._v$2 = _v$2);
                _v$3 !== _p$._v$3 && setAttribute(_el$2, "src", _p$._v$3 = _v$3);
                _v$4 !== _p$._v$4 && setAttribute(_el$2, "allow", _p$._v$4 = _v$4);
                _v$5 !== _p$._v$5 && _el$2.style.setProperty("width", _p$._v$5 = _v$5);
                _v$6 !== _p$._v$6 && _el$2.style.setProperty("height", _p$._v$6 = _v$6);
                return _p$;
            }, {
                _v$: undefined,
                _v$2: undefined,
                _v$3: undefined,
                _v$4: undefined,
                _v$5: undefined,
                _v$6: undefined
            });
            return _el$;
        }
    });
};

const _tmpl$ = /*#__PURE__*/ template(`<div class="youtube-solid-social"><iframe class="youtube" allow="accelerometer; autoplay; encrypted-media; fullscreen; gyroscope; picture-in-picture"></iframe></div>`, 4);
const YouTube = properties => {
    const properties_ = mergeProps({
        aspectRatio: '16:9',
        autoPlay: false,
        skipTo: {
            h: 0,
            m: 0,
            s: 0
        },
        noCookie: false
    }, properties);
    const { h, m, s } = properties_.skipTo;
    const tH = h * 60;
    const tM = m * 60;
    const startTime = tH + tM + s;
    const source = `//www.youtube${properties_.noCookie ? '-nocookie' : ''}.com/embed/${properties_.youTubeId ? `${properties_.youTubeId}?&autoplay=${properties_.autoPlay.toString()}&start=${startTime}` : `&videoseries?list=${properties_.youTubePlaylistId ?? ''}`}`;
    return createComponent(GeneralObserver, {
        get children() {
            const _el$ = _tmpl$.cloneNode(true), _el$2 = _el$.firstChild;
            spread(_el$2, () => createTestId('youtube'), false, false);
            setAttribute(_el$2, "src", source);
            _el$2.style.setProperty("position", "absolute");
            _el$2.style.setProperty("top", "0");
            _el$2.style.setProperty("left", "0");
            _el$2.style.setProperty("width", "100%");
            _el$2.style.setProperty("height", "100%");
            effect(_p$ => {
                const _v$ = {
                    position: 'relative',
                    width: '100%',
                    ...getPadding$1(properties_.aspectRatio)
                }, _v$2 = `youTube-${properties_.youTubeId ?? properties_.youTubePlaylistId ?? ''}`;
                _p$._v$ = style(_el$, _v$, _p$._v$);
                _v$2 !== _p$._v$2 && setAttribute(_el$2, "title", _p$._v$2 = _v$2);
                return _p$;
            }, {
                _v$: undefined,
                _v$2: undefined
            });
            return _el$;
        }
    });
};

export { AirtableBase, AirtableForm, Buzzsprout, Cinnamon, CodePen, CodeSandbox, EggheadLesson, Figma, Flickr, Gist, Instagram, Lbry, LinkedInBadge, ListenNotesEpisode, Pin, PinterestBoard, PinterestFollowButton, SimplecastEpisode, Snack, SoundCloud, Spotify, Strava, TikTok, Tweet, Twitch, TwitterFollowButton, TwitterHashtagButton, TwitterList, TwitterMentionButton, TwitterTimeline, Vimeo, Whimsical, Wikipedia, Wistia, YouTube };
